@@ -1,4 +1,4 @@
-# $Id: LazyInflate.pm 7 2005-06-01 06:36:24Z daisuke $
+# $Id: LazyInflate.pm 3 2005-02-22 01:38:39Z daisuke $
 #
 # Daisuke Maki <dmaki@cpan.org>
 # All rights reserved.
@@ -7,7 +7,7 @@ package Class::DBI::LazyInflate;
 use strict;
 use Data::Lazy;
 use vars qw($VERSION);
-$VERSION = '0.03';
+$VERSION = '0.01';
 
 sub import
 {
@@ -15,52 +15,18 @@ sub import
     my($caller) = caller();
     {
         no strict 'refs';
-        *{ "${caller}::has_lazy" } =
-            $Class::DBI::VERSION >= 0.96 ?
-            \&has_lazy_new
-            \&has_lazy_old;
+        *{ "${caller}::has_lazy" } = \&has_lazy;
     }
 }
 
-# 0.96 and up
-sub has_lazy_new
+sub has_lazy
 {
     my($class, $column, $colclass, %args) = @_;
 
-    my $inflate      = $args{inflate} || 
-        ($colclass->isa('Class::DBI') ? '_simple_bless' : 'new');
+    my $inflate = delete $args{inflate};
     my $lazy_inflate = sub {
         my $value = shift;
-        my $self  = shift;
-
-        tie $value, 'Data::Lazy',
-            sub {
-                ref($inflate) eq 'CODE' ?
-                    $inflate->($value, $self) :
-                    $colclass->$inflate($value, $self) },
-            LAZY_STOREVALUE;
-        $value;
-    };
-    $class->has_a(
-        $column, $colclass,
-        inflate => $lazy_inflate, deflate => $args{deflate}
-    );
-}
-sub has_lazy_old
-{
-    my($class, $column, $colclass, %args) = @_;
-
-    my $inflate      = $args{inflate} || 
-        ($colclass->isa('Class::DBI') ? '_simple_bless' : 'new');
-    my $lazy_inflate = sub {
-        my $value = shift;
-
-        tie $value, 'Data::Lazy',
-            sub {
-                ref($inflate) eq 'CODE' ?
-                    $inflate->($value) :
-                    $colclass->$inflate($value) },
-            LAZY_STOREVALUE;
+        tie $value, 'Data::Lazy', sub { $inflate->($value) }, LAZY_STOREVALUE;
         $value;
     };
     $class->has_a(
@@ -86,7 +52,7 @@ Class::DBI::LazyInflate - Defer Inflating Of Columns Until They Are Used
   use DateTime::Format::MySQL;
 
   __PACKAGE__->has_lazy(
-    'lastmod', 'DateTime',
+    'lastmod',
     inflate => sub { DateTime::Format::MySQL->parse_datetime(shift) },
     deflate => sub { DateTime::Format::MySQL->format_datetime(shift) },
   );
@@ -96,9 +62,6 @@ Class::DBI::LazyInflate - Defer Inflating Of Columns Until They Are Used
 
   $obj->lastmod(DateTime->now());
 
-  # Specify another Class::DBI type as a column:
-  __PACKAGE__->has_lazy(cdbi_field => 'MyData');
-
 =head1 DESCRIPTION
 
 Class::DBI::LazyInflate is a utility class that allows you to create DBI
@@ -117,10 +80,7 @@ until when you really need it
 
 has_lazy() declares that column is to be inflated lazily, and is installed
 to the calling package's namespace upon call to "use Class::DBI::LazyInflate".
-The arguments are exactly the same as has_a().
-
-If inflate is not specified, it will lazily perform the default inflate
-procedure that Class::DBI uses.
+The arguments are exactly the same has has_a().
 
 =head1 AUTHOR
 
